@@ -1,16 +1,8 @@
-/*
+/* SPDX-License-Identifier: LGPL-2.1-only */
+/**
  * Copyright IBM Corporation. 2007
  *
  * Author:	Balbir Singh <balbir@linux.vnet.ibm.com>
- *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of version 2.1 of the GNU Lesser General Public License
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it would be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- *
  */
 
 #ifndef _LIBCGROUP_H
@@ -25,6 +17,7 @@
 #include <libcgroup/tasks.h>
 #include <libcgroup/config.h>
 #include <libcgroup/log.h>
+#include <libcgroup/tools.h>
 
 #undef _LIBCGROUP_H_INSIDE
 
