@@ -1,3 +1,4 @@
+/* SPDX-License-Identifier: LGPL-2.1-only */
 #ifndef _LIBCGROUP_GROUPS_H
 #define _LIBCGROUP_GROUPS_H
 
@@ -15,6 +16,13 @@
 extern "C" {
 #endif
 
+enum cg_version_t {
+	CGROUP_UNK = 0,
+	CGROUP_V1,
+	CGROUP_V2,
+	CGROUP_DISK = 0xFF,
+};
+
 /**
  * Flags for cgroup_delete_cgroup_ext().
  */
@@ -34,7 +42,7 @@ enum cgroup_delete_flag {
 	 * no processes inside. This flag cannot be used with
 	 * CGFLAG_DELETE_RECURSIVE.
 	 */
-	CGFLAG_DELETE_EMPTY_ONLY	= 4,
+	CGFLAG_DELETE_EMPTY_ONLY = 4,
 };
 
 /**
@@ -133,9 +141,9 @@ struct cgroup_controller;
  * control group in kernel, only new <tt>struct cgroup</tt> inside libcgroup!
  *
  * @param name Path to the group, relative from root group. Use @c "/" or @c "."
- * 	for the root group itself and @c "/foo/bar/baz" or @c "foo/bar/baz" for
- * 	subgroups.
- * 	@todo suggest one preferred way, either "/foo" or "foo".
+ *	for the root group itself and @c "/foo/bar/baz" or @c "foo/bar/baz" for
+ *	subgroups.
+ *	@todo suggest one preferred way, either "/foo" or "foo".
  * @returns Created group or NULL on error.
  */
 struct cgroup *cgroup_new_cgroup(const char *name);
@@ -145,7 +153,7 @@ struct cgroup *cgroup_new_cgroup(const char *name);
  * libcgroup structure, not the kernel control group.
  *
  * @param cgroup
- * @param name Name of the controller, e.g. "freezer".
+ * @param name The name of the controller, e.g. "freezer".
  * @return Created controller or NULL on error.
  */
 struct cgroup_controller *cgroup_add_controller(struct cgroup *cgroup,
@@ -166,10 +174,10 @@ int cgroup_add_all_controllers(struct cgroup *cgroup);
  * The controller must be added before using cgroup_add_controller() or loaded
  * from kernel using cgroup_get_cgroup().
  * @param cgroup
- * @param name Name of the controller, e.g. "freezer".
+ * @param name The name of the controller, e.g. "freezer".
  */
 struct cgroup_controller *cgroup_get_controller(struct cgroup *cgroup,
-							const char *name);
+						const char *name);
 
 /**
  * Free internal @c cgroup structure. This function frees also all controllers
@@ -185,7 +193,6 @@ void cgroup_free(struct cgroup **cgroup);
  */
 void cgroup_free_controllers(struct cgroup *cgroup);
 
-
 /**
  * @}
  * @name Group manipulation API
@@ -204,8 +211,8 @@ void cgroup_free_controllers(struct cgroup *cgroup);
  * permissions set by cgroup_set_permissions.
  * @param cgroup
  * @param ignore_ownership When nozero, all errors are ignored when setting
- * 	owner of the group and/or its tasks file.
- * 	@todo what is ignore_ownership good for?
+ *	owner of the group and/or its tasks file.
+ *	@todo what is ignore_ownership good for?
  * @retval #ECGROUPNOTEQUAL if not all specified controller parameters
  *      were successfully set.
  */
@@ -225,15 +232,15 @@ int cgroup_create_cgroup(struct cgroup *cgroup, int ignore_ownership);
  * crate subgroup of root group in just one hierarchy with this function!
  *
  * @param cgroup The cgroup to create. Only it's name is used, everything else
- * 	is discarded.
+ *	is discarded.
  * @param ignore_ownership When nozero, all errors are ignored when setting
- * 	owner of the group and/or its tasks file.
- * 	@todo what is ignore_ownership good for?
+ *	owner of the group and/or its tasks file.
+ *	@todo what is ignore_ownership good for?
  * @retval #ECGROUPNOTEQUAL if not all inherited controller parameters
  *      were successfully set (this is expected).
  */
 int cgroup_create_cgroup_from_parent(struct cgroup *cgroup,
-		int ignore_ownership);
+				     int ignore_ownership);
 
 /**
  * Physically modify a control group in kernel. All parameters added by
@@ -276,7 +283,6 @@ int cgroup_delete_cgroup(struct cgroup *cgroup, int ignore_migration);
  */
 int cgroup_delete_cgroup_ext(struct cgroup *cgroup, int flags);
 
-
 /**
  * @}
  * @name Other functions
@@ -302,7 +308,7 @@ int cgroup_delete_cgroup_ext(struct cgroup *cgroup, int flags);
  * different owner of tasks file?
  *
  * @param cgroup The cgroup to load. Only it's name is used, everything else
- * 	is replaced.
+ *	is replaced.
  */
 int cgroup_get_cgroup(struct cgroup *cgroup);
 
@@ -325,7 +331,7 @@ int cgroup_copy_cgroup(struct cgroup *dst, struct cgroup *src);
  * @retval 0  if the groups are the same.
  * @retval #ECGROUPNOTEQUAL if the groups are not the same.
  * @retval #ECGCONTROLLERNOTEQUAL if the only difference are controllers,
- * 	parameters or their values.
+ *	parameters or their values.
  */
 int cgroup_compare_cgroup(struct cgroup *cgroup_a, struct cgroup *cgroup_b);
 
@@ -340,7 +346,7 @@ int cgroup_compare_cgroup(struct cgroup *cgroup_a, struct cgroup *cgroup_b);
  * @retval #ECGCONTROLLERNOTEQUAL if the controllers are not equal.
  */
 int cgroup_compare_controllers(struct cgroup_controller *cgca,
-					struct cgroup_controller *cgcb);
+			       struct cgroup_controller *cgcb);
 
 /**
  * Set owner of the group control files and the @c tasks file. This function
@@ -351,12 +357,12 @@ int cgroup_compare_controllers(struct cgroup_controller *cgca,
  * @param tasks_uid UID of the owner of group's @c tasks file.
  * @param tasks_gid GID of the owner of group's @c tasks file.
  * @param control_uid UID of the owner of group's control files (i.e.
- * 	parameters).
+ *	parameters).
  * @param control_gid GID of the owner of group's control files (i.e.
- * 	parameters).
+ *	parameters).
  */
 int cgroup_set_uid_gid(struct cgroup *cgroup, uid_t tasks_uid, gid_t tasks_gid,
-					uid_t control_uid, gid_t control_gid);
+		       uid_t control_uid, gid_t control_gid);
 
 /**
  * Return owners of the group's @c tasks file and control files.
@@ -364,7 +370,8 @@ int cgroup_set_uid_gid(struct cgroup *cgroup, uid_t tasks_uid, gid_t tasks_gid,
  * cgroup_set_uid_gid() or cgroup_get_cgroup() to fill it.
  */
 int cgroup_get_uid_gid(struct cgroup *cgroup, uid_t *tasks_uid,
-		gid_t *tasks_gid, uid_t *control_uid, gid_t *control_gid);
+		       gid_t *tasks_gid, uid_t *control_uid,
+		       gid_t *control_gid);
 
 /**
  * Stores given file permissions of the group's control and tasks files
@@ -379,8 +386,8 @@ int cgroup_get_uid_gid(struct cgroup *cgroup, uid_t *tasks_uid,
  * @param task_fperm File permissions for task file.
  */
 void cgroup_set_permissions(struct cgroup *cgroup,
-		mode_t control_dperm, mode_t control_fperm,
-		mode_t task_fperm);
+			    mode_t control_dperm, mode_t control_fperm,
+			    mode_t task_fperm);
 
 /**
  * @}
@@ -398,12 +405,13 @@ void cgroup_set_permissions(struct cgroup *cgroup,
  * Use cgroup_modify_cgroup() or cgroup_create_cgroup() to write it to kernel.
  *
  * @param controller
- * @param name Name of the parameter.
+ * @param name The name of the parameter.
  * @param value
  *
  */
 int cgroup_add_value_string(struct cgroup_controller *controller,
-				const char *name, const char *value);
+			    const char *name, const char *value);
+
 /**
  * Add parameter and its value to internal @c libcgroup structures.
  * Use cgroup_modify_cgroup() or cgroup_create_cgroup() to write it to kernel.
@@ -411,34 +419,36 @@ int cgroup_add_value_string(struct cgroup_controller *controller,
  * after return from the function.
  *
  * @param controller
- * @param name Name of the parameter.
+ * @param name The name of the parameter.
  * @param value
  *
  */
 int cgroup_add_value_int64(struct cgroup_controller *controller,
-				const char *name, int64_t value);
+			   const char *name, int64_t value);
+
 /**
  * Add parameter and its value to internal @c libcgroup structures.
  * Use cgroup_modify_cgroup() or cgroup_create_cgroup() to write it to kernel.
  *
  * @param controller
- * @param name Name of the parameter.
+ * @param name The name of the parameter.
  * @param value
  *
  */
 int cgroup_add_value_uint64(struct cgroup_controller *controller,
-				const char *name, u_int64_t value);
+			    const char *name, u_int64_t value);
+
 /**
  * Add parameter and its value to internal @c libcgroup structures.
  * Use cgroup_modify_cgroup() or cgroup_create_cgroup() to write it to kernel.
  *
  * @param controller
- * @param name Name of the parameter.
+ * @param name The name of the parameter.
  * @param value
  *
  */
 int cgroup_add_value_bool(struct cgroup_controller *controller,
-				const char *name, bool value);
+			  const char *name, bool value);
 
 /**
  * Read a parameter value from @c libcgroup internal structures.
@@ -452,52 +462,55 @@ int cgroup_add_value_bool(struct cgroup_controller *controller,
  * @todo rephrase, it's too vague... How big is the buffer actually?
  *
  * @param controller
- * @param name Name of the parameter.
+ * @param name The name of the parameter.
  * @param value
  */
 int cgroup_get_value_string(struct cgroup_controller *controller,
-					const char *name, char **value);
+			    const char *name, char **value);
 /**
  * Read a parameter value from @c libcgroup internal structures.
  * Use @c cgroup_get_cgroup() to fill these structures with data from kernel.
  *
  * @param controller
- * @param name Name of the parameter.
+ * @param name The name of the parameter.
  * @param value
  */
 int cgroup_get_value_int64(struct cgroup_controller *controller,
-					const char *name, int64_t *value);
+			   const char *name, int64_t *value);
+
 /**
  * Read a parameter value from @c libcgroup internal structures.
  * Use @c cgroup_get_cgroup() to fill these structures with data from kernel.
  *
  * @param controller
- * @param name Name of the parameter.
+ * @param name The name of the parameter.
  * @param value
  */
 int cgroup_get_value_uint64(struct cgroup_controller *controller,
-					const char *name, u_int64_t *value);
+			    const char *name, u_int64_t *value);
+
 /**
  * Read a parameter value from @c libcgroup internal structures.
  * Use @c cgroup_get_cgroup() to fill these structures with data from kernel.
  *
  * @param controller
- * @param name Name of the parameter.
+ * @param name The name of the parameter.
  * @param value
  */
 int cgroup_get_value_bool(struct cgroup_controller *controller,
-						const char *name, bool *value);
+			  const char *name, bool *value);
 
 /**
  * Set a parameter value in @c libcgroup internal structures.
  * Use cgroup_modify_cgroup() or cgroup_create_cgroup() to write it to kernel.
  *
  * @param controller
- * @param name Name of the parameter.
+ * @param name The name of the parameter.
  * @param value
  */
 int cgroup_set_value_string(struct cgroup_controller *controller,
-					const char *name, const char *value);
+			    const char *name, const char *value);
+
 /**
  * Set a parameter value in @c libcgroup internal structures.
  * Use cgroup_modify_cgroup() or cgroup_create_cgroup() to write it to kernel.
@@ -505,31 +518,33 @@ int cgroup_set_value_string(struct cgroup_controller *controller,
  * after return from the function.
  *
  * @param controller
- * @param name Name of the parameter.
+ * @param name The name of the parameter.
  * @param value
  */
 int cgroup_set_value_int64(struct cgroup_controller *controller,
-					const char *name, int64_t value);
+			   const char *name, int64_t value);
 /**
  * Set a parameter value in @c libcgroup internal structures.
  * Use cgroup_modify_cgroup() or cgroup_create_cgroup() to write it to kernel.
  *
  * @param controller
- * @param name Name of the parameter.
+ * @param name The name of the parameter.
  * @param value
  */
 int cgroup_set_value_uint64(struct cgroup_controller *controller,
-					const char *name, u_int64_t value);
+			    const char *name, u_int64_t value);
+
 /**
  * Set a parameter value in @c libcgroup internal structures.
  * Use cgroup_modify_cgroup() or cgroup_create_cgroup() to write it to kernel.
  *
  * @param controller
- * @param name Name of the parameter.
+ * @param name The name of the parameter.
  * @param value
  */
 int cgroup_set_value_bool(struct cgroup_controller *controller,
-						const char *name, bool value);
+			  const char *name, bool value);
+
 /**
  * Return the number of variables for the specified controller in @c libcgroup
  * internal structures. Use cgroup_get_cgroup() to fill these structures with
@@ -550,7 +565,7 @@ int cgroup_get_value_name_count(struct cgroup_controller *controller);
  * do not free it.
  *
  * @param controller
- * @param index Index of the parameter.
+ * @param index The index of the parameter.
  * @return Name of the parameter.
  */
 char *cgroup_get_value_name(struct cgroup_controller *controller, int index);
@@ -575,7 +590,7 @@ int cgroup_get_procs(char *name, char *controller, pid_t **pids, int *size);
  * @param filem_change Denotes whether the directory change should be done
  */
 int cg_chmod_recursive(struct cgroup *cgroup, mode_t dir_mode,
-	int dirm_change, mode_t file_mode, int filem_change);
+		       int dirm_change, mode_t file_mode, int filem_change);
 
 /**
  *  Get the name of the cgroup from a given cgroup
@@ -583,6 +598,44 @@ int cg_chmod_recursive(struct cgroup *cgroup, mode_t dir_mode,
  */
 char *cgroup_get_cgroup_name(struct cgroup *cgroup);
 
+/*
+ * Convert from one cgroup version to another version
+ *
+ * @param out_cgroup Destination cgroup
+ * @param out_version Destination cgroup version
+ * @param in_cgroup Source cgroup
+ * @param in_version Source cgroup version, only used if set to v1 or v2
+ *
+ * @return 0 on success
+ *         ECGFAIL conversion failed
+ *         ECGCONTROLLERNOTEQUAL incorrect controller version provided
+ */
+int cgroup_convert_cgroup(struct cgroup * const out_cgroup,
+			  enum cg_version_t out_version,
+			  const struct cgroup * const in_cgroup,
+			  enum cg_version_t in_version);
+
+/**
+ * List the mount paths, that matches the specified version
+ *
+ *	@param cgrp_version The cgroup type/version
+ *	@param mount_paths Holds the list of mount paths
+ *	@return 0 success and list of mounts paths in mount_paths
+ *		ECGOTHER on failure and mount_paths is NULL.
+ */
+int cgroup_list_mount_points(const enum cg_version_t cgrp_version,
+			     char ***mount_paths);
+
+/**
+ * Get the cgroup version of a controller.  Version is set to CGROUP_UNK
+ * if the version cannot be determined.
+ *
+ * @param controller The controller of interest
+ * @param version The version of the controller
+ */
+int cgroup_get_controller_version(const char * const controller,
+				  enum cg_version_t * const version);
+
 /**
  * @}
  * @}
