@@ -9,7 +9,28 @@
 #include <features.h>
 #endif
 
-__BEGIN_DECLS
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+#define CGROUP_VER_MAJOR	3
+#define CGROUP_VER_MINOR	0
+#define CGROUP_VER_RELEASE	0
+
+struct cgroup_library_version {
+	unsigned int major;
+	unsigned int minor;
+	unsigned int release;
+};
+
+/**
+ * Query the library version information
+ *
+ * This function returns a pointer to a populated cgroup_library_version
+ * struct.  The caller does not need to free the structure when finished.
+ *
+ */
+const struct cgroup_library_version *cgroup_version(void);
 
 /**
  * @defgroup group_init 1. Initialization
@@ -35,6 +56,10 @@ __BEGIN_DECLS
 /**
  * Initialize libcgroup. Information about mounted hierarchies are examined
  * and cached internally (just what's mounted where, not the groups themselves).
+ *
+ * If the cgroup logging was not set using cgroup_set_logger() or
+ * cgroup_set_default_logger() before calling cgroup_init(), the default logger
+ * is automatically set, logging CGROUP_LOG_ERROR messages.
  */
 int cgroup_init(void);
 
@@ -46,7 +71,7 @@ int cgroup_init(void);
  * and cgroup_get_subsys_mount_point_end() to get all of them.
  * @param controller Name of the controller
  * @param mount_point The string where the mount point location is stored.
- * 	Please note, the caller must free the mount_point.
+ *	Please note, the caller must free the mount_point.
  */
 int cgroup_get_subsys_mount_point(const char *controller, char **mount_point);
 
@@ -54,6 +79,8 @@ int cgroup_get_subsys_mount_point(const char *controller, char **mount_point);
  * @}
  * @}
  */
-__END_DECLS
+#ifdef __cplusplus
+} /* extern "C" */
+#endif
 
 #endif /* _LIBCGROUP_INIT_H */
