@@ -1,58 +1,49 @@
+// SPDX-License-Identifier: LGPL-2.1-only
+#include "tools-common.h"
+
 #include <libcgroup.h>
 #include <libcgroup-internal.h>
 
 #include <dirent.h>
 #include <getopt.h>
 #include <pthread.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
+#include <stdio.h>
 
-#include "tools-common.h"
+#define MODE_SHOW_HEADERS	1
+#define MODE_SHOW_NAMES		2
 
-#define MODE_SHOW_HEADERS		1
-#define MODE_SHOW_NAMES			2
+#define LL_MAX			100
 
-#define LL_MAX				100
-
-static struct option const long_options[] =
-{
-	{"variable", required_argument, NULL, 'r'},
-	{"help", no_argument, NULL, 'h'},
-	{"all",  no_argument, NULL, 'a'},
-	{"values-only", no_argument, NULL, 'v'},
+static const struct option long_options[] = {
+	{"variable",	required_argument, NULL, 'r'},
+	{"help",	      no_argument, NULL, 'h'},
+	{"all",		      no_argument, NULL, 'a'},
+	{"values-only",	      no_argument, NULL, 'v'},
 	{NULL, 0, NULL, 0}
 };
 
 static void usage(int status, const char *program_name)
 {
 	if (status != 0) {
-		fprintf(stderr, "Wrong input parameters,"
-			" try %s -h' for more information.\n",
-			program_name);
+		err("Wrong input parameters, try %s -h' for more information.\n", program_name);
 		return;
 	}
-	printf("Usage: %s [-nv] [-r <name>] [-g <controllers>] "\
-		"[-a] <path> ...\n"\
-		"   or: %s [-nv] [-r <name>] -g <controllers>:<path> ...\n",
-		program_name, program_name);
-	printf("Print parameter(s) of given group(s).\n");
-	printf("  -a, --all			Print info about all relevant "\
-		"controllers\n");
-	printf("  -g <controllers>		Controller which info should "\
-		"be displayed\n");
-	printf("  -g <controllers>:<path>	Control group which info "\
-		"should be displayed\n");
-	printf("  -h, --help			Display this help\n");
-	printf("  -n				Do not print headers\n");
-	printf("  -r, --variable  <name>	Define parameter to display\n");
-	printf("  -v, --values-only		Print only values, not "\
-		"parameter names\n");
+	info("Usage: %s [-nv] [-r <name>] [-g <controllers>] [-a] <path> ...\n", program_name);
+	info("Print parameter(s) of given group(s).\n");
+	info("  -a, --all			Print info about all relevant controllers\n");
+	info("  -g <controllers>		Controller which info should be displayed\n");
+	info("  -g <controllers>:<path>	Control group which info should be displayed\n");
+	info("  -h, --help			Display this help\n");
+	info("  -n				Do not print headers\n");
+	info("  -r, --variable <name>		Define parameter to display\n");
+	info("  -v, --values-only		Print only values, not ");
+	info("parameter names\n");
 }
 
-static int get_controller_from_name(const char * const name,
-                                    char **controller)
+static int get_controller_from_name(const char * const name, char **controller)
 {
 	char *dot;
 
@@ -62,21 +53,20 @@ static int get_controller_from_name(const char * const name,
 
 	dot = strchr(*controller, '.');
 	if (dot == NULL) {
-		fprintf(stderr, "cgget: error parsing parameter name\n" \
-			" '%s'", name);
+		err("cgget: error parsing parameter name '%s'", name);
 		return ECGINVAL;
 	}
-
 	*dot = '\0';
+
 	return 0;
 }
 
 static int create_cg(struct cgroup **cg_list[], int * const cg_list_len)
 {
-	*cg_list = realloc(*cg_list,
-			((*cg_list_len) + 1) * sizeof(struct cgroup *));
+	*cg_list = realloc(*cg_list, ((*cg_list_len) + 1) * sizeof(struct cgroup *));
 	if ((*cg_list) == NULL)
 		return ECGCONTROLLERCREATEFAILED;
+
 	memset(&(*cg_list)[*cg_list_len], 0, sizeof(struct cgroup *));
 
 	(*cg_list)[*cg_list_len] = cgroup_new_cgroup("");
@@ -84,6 +74,7 @@ static int create_cg(struct cgroup **cg_list[], int * const cg_list_len)
 		return ECGCONTROLLERCREATEFAILED;
 
 	(*cg_list_len)++;
+
 	return 0;
 }
 
@@ -101,9 +92,10 @@ static int parse_a_flag(struct cgroup **cg_list[], int * const cg_list_len)
 			goto out;
 	}
 
-	/* if "-r" was provided, then we know that the cgroup(s) will be an
-	 * optarg at the end with no flag.  Let's temporarily populate the
-	 * first cgroup with the requested control values.
+	/*
+	 * if "-r" was provided, then we know that the cgroup(s) will be
+	 * an optarg at the end with no flag.  Let's temporarily populate
+	 * the first cgroup with the requested control values.
 	 */
 	cg = (*cg_list)[0];
 
@@ -113,15 +105,16 @@ static int parse_a_flag(struct cgroup **cg_list[], int * const cg_list_len)
 		if (!cgc) {
 			cgc = cgroup_add_controller(cg, controller.name);
 			if (!cgc) {
-				ret = ECGCONTROLLERCREATEFAILED;
+				err("cgget: cannot find controller '%s'\n", controller.name);
+				ret = ECGOTHER;
 				goto out;
 			}
 		}
-
 		ret = cgroup_get_controller_next(&handle, &controller);
 	}
 	if (ret == ECGEOF)
-		/* we successfully reached the end of the controller list;
+		/*
+		 * we successfully reached the end of the controller list;
 		 * this is not an error
 		 */
 		ret = 0;
@@ -132,6 +125,7 @@ static int parse_a_flag(struct cgroup **cg_list[], int * const cg_list_len)
 
 out:
 	cgroup_get_controller_end(&handle);
+
 	return ret;
 }
 
@@ -149,9 +143,10 @@ static int parse_r_flag(struct cgroup **cg_list[], int * const cg_list_len,
 			goto out;
 	}
 
-	/* if "-r" was provided, then we know that the cgroup(s) will be an
-	 * optarg at the end with no flag.  Let's temporarily populate the
-	 * first cgroup with the requested control values.
+	/*
+	 * if "-r" was provided, then we know that the cgroup(s) will be
+	 * an optarg at the end with no flag.  Let's temporarily populate
+	 * the first cgroup with the requested control values.
 	 */
 	cg = (*cg_list)[0];
 
@@ -163,7 +158,8 @@ static int parse_r_flag(struct cgroup **cg_list[], int * const cg_list_len,
 	if (!cgc) {
 		cgc = cgroup_add_controller(cg, cntl_value_controller);
 		if (!cgc) {
-			ret = ECGCONTROLLERCREATEFAILED;
+			err("cgget: cannot find controller '%s'\n", cntl_value_controller);
+			ret = ECGOTHER;
 			goto out;
 		}
 	}
@@ -173,11 +169,12 @@ static int parse_r_flag(struct cgroup **cg_list[], int * const cg_list_len,
 out:
 	if (cntl_value_controller)
 		free(cntl_value_controller);
+
 	return ret;
 }
 
-static int parse_g_flag_no_colon(struct cgroup **cg_list[],
-		int * const cg_list_len, const char * const ctrl_str)
+static int parse_g_flag_no_colon(struct cgroup **cg_list[], int * const cg_list_len,
+				 const char * const ctrl_str)
 {
 	struct cgroup_controller *cgc;
 	struct cgroup *cg = NULL;
@@ -194,7 +191,8 @@ static int parse_g_flag_no_colon(struct cgroup **cg_list[],
 			goto out;
 	}
 
-	/* if "-g <controller>" was provided, then we know that the cgroup(s)
+	/*
+	 * if "-g <controller>" was provided, then we know that the cgroup(s)
 	 * will be an optarg at the end with no flag.  Let's temporarily
 	 * populate the first cgroup with the requested control values.
 	 */
@@ -204,7 +202,8 @@ static int parse_g_flag_no_colon(struct cgroup **cg_list[],
 	if (!cgc) {
 		cgc = cgroup_add_controller(cg, ctrl_str);
 		if (!cgc) {
-			ret = ECGCONTROLLERCREATEFAILED;
+			err("cgget: cannot find controller '%s'\n", ctrl_str);
+			ret = ECGOTHER;
 			goto out;
 		}
 	}
@@ -229,12 +228,11 @@ static int split_cgroup_name(const char * const ctrl_str, char *cg_name)
 	return 0;
 }
 
-static int split_controllers(const char * const in,
-			     char **ctrl[], int * const ctrl_len)
+static int split_controllers(const char * const in, char **ctrl[], int * const ctrl_len)
 {
 	char *copy, *tok, *colon, *saveptr = NULL;
-	char **tmp;
 	int ret = 0;
+	char **tmp;
 
 	copy = strdup(in);
 	if (!copy)
@@ -265,11 +263,12 @@ static int split_controllers(const char * const in,
 out:
 	if (saveptr)
 		free(saveptr);
+
 	return ret;
 }
 
-static int parse_g_flag_with_colon(struct cgroup **cg_list[],
-		int * const cg_list_len, const char * const ctrl_str)
+static int parse_g_flag_with_colon(struct cgroup **cg_list[], int * const cg_list_len,
+				   const char * const ctrl_str)
 {
 	struct cgroup_controller *cgc;
 	struct cgroup *cg = NULL;
@@ -296,7 +295,8 @@ static int parse_g_flag_with_colon(struct cgroup **cg_list[],
 		if (!cgc) {
 			cgc = cgroup_add_controller(cg, controllers[i]);
 			if (!cgc) {
-				ret = ECGCONTROLLERCREATEFAILED;
+				err("cgget: cannot find controller '%s'\n", controllers[i]);
+				ret = ECGOTHER;
 				goto out;
 			}
 		}
@@ -305,6 +305,7 @@ static int parse_g_flag_with_colon(struct cgroup **cg_list[],
 out:
 	for (i = 0; i < controllers_len; i++)
 		free(controllers[i]);
+
 	return ret;
 }
 
@@ -314,20 +315,23 @@ static int parse_opt_args(int argc, char *argv[], struct cgroup **cg_list[],
 	struct cgroup *cg = NULL;
 	int ret = 0;
 
-	/* The first cgroup was temporarily populated and requires
-	 * the user to provide a cgroup name as an opt */
+	/*
+	 * The first cgroup was temporarily populated and requires the
+	 * user to provide a cgroup name as an opt
+	 */
 	if (argv[optind] == NULL && first_cg_is_dummy) {
 		usage(1, argv[0]);
 		exit(-1);
 	}
 
-	/* The user has provided a cgroup and controller via the
-	 * -g <controller>:<cgroup> flag and has also provided a cgroup via
-	 * the optind.  This was not supported by the previous cgget
+	/*
+	 * The user has provided a cgroup and controller via the
+	 * -g <controller>:<cgroup> flag and has also provided a cgroup
+	 *  via the optind.  This was not supported by the previous cgget
 	 * implementation.  Continue that approach.
 	 *
 	 * Example of a command that will hit this code:
-	 * 	$ cgget -g cpu:mycgroup mycgroup
+	 *	$ cgget -g cpu:mycgroup mycgroup
 	 */
 	if (argv[optind] != NULL && (*cg_list_len) > 0 &&
 	    strcmp((*cg_list)[0]->name, "") != 0) {
@@ -342,7 +346,8 @@ static int parse_opt_args(int argc, char *argv[], struct cgroup **cg_list[],
 			cg = NULL;
 
 		if ((*cg_list_len) == 0) {
-			/* The user didn't provide a '-r' or '-g' flag.
+			/*
+			 * The user didn't provide a '-r' or '-g' flag.
 			 * The parse_a_flag() function can be reused here
 			 * because we both have the same use case - gather
 			 * all the data about this particular cgroup.
@@ -351,14 +356,13 @@ static int parse_opt_args(int argc, char *argv[], struct cgroup **cg_list[],
 			if (ret)
 				goto out;
 
-			strncpy((*cg_list)[(*cg_list_len) - 1]->name,
-				argv[optind],
+			strncpy((*cg_list)[(*cg_list_len) - 1]->name, argv[optind],
 				sizeof((*cg_list)[(*cg_list_len) - 1]->name) - 1);
 		} else if (cg != NULL && strlen(cg->name) == 0) {
-			/* this cgroup was created based upon control/value
+			/*
+			 * this cgroup was created based upon control/value
 			 * pairs or with a -g <controller> option.  we'll
-			 * populate it with the parameter provided by the
-			 * user
+			 * populate it with the parameter provided by the user
 			 */
 			strncpy(cg->name, argv[optind], sizeof(cg->name) - 1);
 		} else {
@@ -371,11 +375,9 @@ static int parse_opt_args(int argc, char *argv[], struct cgroup **cg_list[],
 			if (ret)
 				goto out;
 
-			strncpy((*cg_list)[(*cg_list_len) - 1]->name,
-				argv[optind],
+			strncpy((*cg_list)[(*cg_list_len) - 1]->name, argv[optind],
 				sizeof((*cg_list)[(*cg_list_len) - 1]->name) - 1);
 		}
-
 		optind++;
 	}
 
@@ -383,18 +385,17 @@ out:
 	return ret;
 }
 
-static int parse_opts(int argc, char *argv[], struct cgroup **cg_list[],
-		      int * const cg_list_len, int * const mode)
+static int parse_opts(int argc, char *argv[], struct cgroup **cg_list[], int * const cg_list_len,
+		      int * const mode)
 {
 	bool do_not_fill_controller = false;
-	bool fill_controller = false;
 	bool first_cgroup_is_dummy = false;
+	bool fill_controller = false;
 	int ret = 0;
 	int c;
 
 	/* Parse arguments. */
-	while ((c = getopt_long(argc, argv, "r:hnvg:a", long_options, NULL))
-		> 0) {
+	while ((c = getopt_long(argc, argv, "r:hnvg:a", long_options, NULL)) > 0) {
 		switch (c) {
 		case 'h':
 			usage(0, argv[0]);
@@ -418,13 +419,11 @@ static int parse_opts(int argc, char *argv[], struct cgroup **cg_list[],
 			fill_controller = true;
 			if (strchr(optarg, ':') == NULL) {
 				first_cgroup_is_dummy = true;
-				ret = parse_g_flag_no_colon(cg_list,
-					cg_list_len, optarg);
+				ret = parse_g_flag_no_colon(cg_list, cg_list_len, optarg);
 				if (ret)
 					goto err;
 			} else {
-				ret = parse_g_flag_with_colon(cg_list,
-					cg_list_len, optarg);
+				ret = parse_g_flag_with_colon(cg_list, cg_list_len, optarg);
 				if (ret)
 					goto err;
 			}
@@ -447,8 +446,7 @@ static int parse_opts(int argc, char *argv[], struct cgroup **cg_list[],
 		exit(1);
 	}
 
-	ret = parse_opt_args(argc, argv, cg_list, cg_list_len,
-			     first_cgroup_is_dummy);
+	ret = parse_opt_args(argc, argv, cg_list, cg_list_len, first_cgroup_is_dummy);
 	if (ret)
 		goto err;
 
@@ -456,8 +454,7 @@ err:
 	return ret;
 }
 
-static int get_cv_value(struct control_value * const cv,
-			const char * const cg_name,
+static int get_cv_value(struct control_value * const cv, const char * const cg_name,
 			const char * const controller_name)
 {
 	bool is_multiline = false;
@@ -465,26 +462,26 @@ static int get_cv_value(struct control_value * const cv,
 	void *handle, *tmp;
 	int ret;
 
-	ret = cgroup_read_value_begin(controller_name, cg_name, cv->name,
-			&handle, tmp_line, LL_MAX);
+	ret = cgroup_read_value_begin(controller_name, cg_name, cv->name, &handle, tmp_line,
+				      LL_MAX);
 	if (ret == ECGEOF)
 		goto read_end;
 	if (ret != 0) {
 		if (ret == ECGOTHER) {
 			int tmp_ret;
 
-			/* to maintain compatibility with an earlier version
+			/*
+			 * to maintain compatibility with an earlier version
 			 * of cgget, try to determine if the failure was due
 			 * to an invalid controller
 			 */
 			tmp_ret = cgroup_test_subsys_mounted(controller_name);
-			if (tmp_ret == 0)
-				fprintf(stderr, "cgget: cannot find controller " \
-					"'%s' in group '%s'\n", controller_name,
-					cg_name);
-			else
-				fprintf(stderr, "variable file read failed %s\n",
-					cgroup_strerror(ret));
+			if (tmp_ret == 0) {
+				err("cgget: cannot find controller '%s' in group '%s'\n",
+				    controller_name, cg_name);
+			} else {
+				err("variable file read failed %s\n", cgroup_strerror(ret));
+			}
 		}
 
 		goto end;
@@ -496,9 +493,9 @@ static int get_cv_value(struct control_value * const cv,
 	strncpy(cv->value, tmp_line, CG_CONTROL_VALUE_MAX - 1);
 	cv->multiline_value = strdup(cv->value);
 	if (cv->multiline_value == NULL)
-		goto end;
+		goto read_end;
 
-	while((ret = cgroup_read_value_next(&handle, tmp_line, LL_MAX)) == 0) {
+	while ((ret = cgroup_read_value_next(&handle, tmp_line, LL_MAX)) == 0) {
 		if (ret == 0) {
 			is_multiline = true;
 			cv->value[0] = '\0';
@@ -509,7 +506,7 @@ static int get_cv_value(struct control_value * const cv,
 			tmp = realloc(cv->multiline_value, sizeof(char) *
 				(strlen(cv->multiline_value) + strlen(tmp_line) + 3));
 			if (tmp == NULL)
-				goto end;
+				goto read_end;
 
 			cv->multiline_value = tmp;
 			strcat(cv->multiline_value, "\n\t");
@@ -521,13 +518,15 @@ read_end:
 	cgroup_read_value_end(&handle);
 	if (ret == ECGEOF)
 		ret = 0;
-
 end:
 	if (is_multiline == false && cv->multiline_value) {
 		free(cv->multiline_value);
 		cv->multiline_value = NULL;
 	}
 
+	if ((FILE *)handle)
+		fclose((FILE *)handle);
+
 	return ret;
 }
 
@@ -537,11 +536,11 @@ static int indent_multiline_value(struct control_value * const cv)
 	char *tok, *saveptr = NULL;
 
 	tok = strtok_r(cv->value, "\n", &saveptr);
-	strcat(tmp_val, tok);
+	strncat(tmp_val, tok, CG_CONTROL_VALUE_MAX - 1);
 	/* don't indent the first value */
 	while ((tok = strtok_r(NULL, "\n", &saveptr))) {
-		strcat(tmp_val, "\n\t");
-		strcat(tmp_val, tok);
+		strncat(tmp_val, "\n\t", (CG_CONTROL_VALUE_MAX - (strlen(tmp_val) + 1)));
+		strncat(tmp_val, tok, (CG_CONTROL_VALUE_MAX - (strlen(tmp_val) + 1)));
 	}
 
 	cv->multiline_value = strdup(tmp_val);
@@ -551,22 +550,19 @@ static int indent_multiline_value(struct control_value * const cv)
 	return 0;
 }
 
-static int fill_empty_controller(struct cgroup * const cg,
-				 struct cgroup_controller * const cgc)
+static int fill_empty_controller(struct cgroup * const cg, struct cgroup_controller * const cgc)
 {
 	struct dirent *ctrl_dir = NULL;
-	char path[FILENAME_MAX];
 	bool found_mount = false;
 	int i, path_len, ret = 0;
+	char path[FILENAME_MAX];
 	DIR *dir = NULL;
 
 	pthread_rwlock_rdlock(&cg_mount_table_lock);
 
-	for (i = 0; i < CG_CONTROLLER_MAX &&
-			cg_mount_table[i].name[0] != '\0'; i++) {
+	for (i = 0; i < CG_CONTROLLER_MAX && cg_mount_table[i].name[0] != '\0'; i++) {
 		if (strlen(cgc->name) == strlen(cg_mount_table[i].name) &&
-		    strncmp(cgc->name, cg_mount_table[i].name,
-			    strlen(cgc->name)) == 0) {
+		    strncmp(cgc->name, cg_mount_table[i].name, strlen(cgc->name)) == 0) {
 			found_mount = true;
 			break;
 		}
@@ -575,10 +571,8 @@ static int fill_empty_controller(struct cgroup * const cg,
 	if (found_mount == false)
 		goto out;
 
-	if (!cg_build_path_locked(NULL, path,
-				  cg_mount_table[i].name)) {
+	if (!cg_build_path_locked(NULL, path, cg_mount_table[i].name))
 		goto out;
-	}
 
 	path_len = strlen(path);
 	strncat(path, cg->name, FILENAME_MAX - path_len - 1);
@@ -587,8 +581,7 @@ static int fill_empty_controller(struct cgroup * const cg,
 	if (access(path, F_OK))
 		goto out;
 
-	if (!cg_build_path_locked(cg->name, path,
-		cg_mount_table[i].name))
+	if (!cg_build_path_locked(cg->name, path, cg_mount_table[i].name))
 		goto out;
 
 	dir = opendir(path);
@@ -598,23 +591,20 @@ static int fill_empty_controller(struct cgroup * const cg,
 	}
 
 	while ((ctrl_dir = readdir(dir)) != NULL) {
-		/*
-		 * Skip over non regular files
-		 */
+		/* Skip over non regular files */
 		if (ctrl_dir->d_type != DT_REG)
 			continue;
 
 		ret = cgroup_fill_cgc(ctrl_dir, cg, cgc, i);
-		if (ret == ECGFAIL) {
-			closedir(dir);
+		if (ret == ECGFAIL)
 			goto out;
-		}
 
 		if (cgc->index > 0) {
 			cgc->values[cgc->index - 1]->dirty = false;
 
-			/* previous versions of cgget indented the second and
-			 * all subsequent lines.  continue that behavior
+			/*
+			 * previous versions of cgget indented the second
+			 * and all subsequent lines. Continue that behavior
 			 */
 			if (strchr(cgc->values[cgc->index - 1]->value, '\n')) {
 				ret = indent_multiline_value(
@@ -625,17 +615,18 @@ static int fill_empty_controller(struct cgroup * const cg,
 		}
 	}
 
-	closedir(dir);
-
 out:
+	if (dir)
+		closedir(dir);
+
 	pthread_rwlock_unlock(&cg_mount_table_lock);
+
 	return ret;
 }
 
-static int get_controller_values(struct cgroup * const cg,
-				 struct cgroup_controller * const cgc)
+static int get_controller_values(struct cgroup * const cg, struct cgroup_controller * const cgc)
 {
-	int ret;
+	int ret = 0;
 	int i;
 
 	for (i = 0; i < cgc->index; i++) {
@@ -657,7 +648,7 @@ out:
 
 static int get_cgroup_values(struct cgroup * const cg)
 {
-	int ret;
+	int ret = 0;
 	int i;
 
 	for (i = 0; i < cg->index; i++) {
@@ -671,7 +662,7 @@ static int get_cgroup_values(struct cgroup * const cg)
 
 static int get_values(struct cgroup *cg_list[], int cg_list_len)
 {
-	int ret;
+	int ret = 0;
 	int i;
 
 	for (i = 0; i < cg_list_len; i++) {
@@ -686,21 +677,20 @@ static int get_values(struct cgroup *cg_list[], int cg_list_len)
 void print_control_values(const struct control_value * const cv, int mode)
 {
 	if (mode & MODE_SHOW_NAMES)
-		printf("%s: ", cv->name);
+		info("%s: ", cv->name);
 
 	if (cv->multiline_value)
-		printf("%s\n", cv->multiline_value);
+		info("%s\n", cv->multiline_value);
 	else
-		printf("%s\n", cv->value);
+		info("%s\n", cv->value);
 }
 
 void print_controller(const struct cgroup_controller * const cgc, int mode)
 {
 	int i;
 
-	for (i = 0; i < cgc->index; i++) {
+	for (i = 0; i < cgc->index; i++)
 		print_control_values(cgc->values[i], mode);
-	}
 }
 
 static void print_cgroup(const struct cgroup * const cg, int mode)
@@ -708,30 +698,29 @@ static void print_cgroup(const struct cgroup * const cg, int mode)
 	int i;
 
 	if (mode & MODE_SHOW_HEADERS)
-		printf("%s:\n", cg->name);
+		info("%s:\n", cg->name);
 
 	for (i = 0; i < cg->index; i++)
 		print_controller(cg->controller[i], mode);
 
 	if (mode & MODE_SHOW_HEADERS)
-		printf("\n");
+		info("\n");
 }
 
 static void print_cgroups(struct cgroup *cg_list[], int cg_list_len, int mode)
 {
 	int i;
 
-	for (i = 0; i < cg_list_len; i++) {
+	for (i = 0; i < cg_list_len; i++)
 		print_cgroup(cg_list[i], mode);
-	}
 }
 
 int main(int argc, char *argv[])
 {
+	int mode = MODE_SHOW_NAMES | MODE_SHOW_HEADERS;
 	struct cgroup **cg_list = NULL;
 	int cg_list_len = 0;
 	int ret = 0, i;
-	int mode = MODE_SHOW_NAMES | MODE_SHOW_HEADERS;
 
 	/* No parameter on input? */
 	if (argc < 2) {
@@ -741,8 +730,7 @@ int main(int argc, char *argv[])
 
 	ret = cgroup_init();
 	if (ret) {
-		fprintf(stderr, "%s: libcgroup initialization failed: %s\n",
-			argv[0], cgroup_strerror(ret));
+		err("%s: libcgroup initialization failed: %s\n", argv[0], cgroup_strerror(ret));
 		goto err;
 	}
 
