@@ -1,36 +1,35 @@
-/*
+// SPDX-License-Identifier: LGPL-2.1-only
+/**
  * Copyright IBM Corporation. 2008
  *
  * Author:	Dhaval Giani <dhaval@linux.vnet.ibm.com>
  *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of version 2.1 of the GNU Lesser General Public License
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it would be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- *
  * Code initiated and designed by Dhaval Giani. All faults are most likely
  * his mistake.
  */
 
 #define _GNU_SOURCE
 
-#include <errno.h>
 #include <libcgroup.h>
 #include <libcgroup-internal.h>
+
 #include <inttypes.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
+#include <stdio.h>
+#include <errno.h>
 
 static void init_cgroup(struct cgroup *cgroup)
 {
-	cgroup->task_fperm = cgroup->control_fperm = cgroup->control_dperm = NO_PERMS;
-	cgroup->control_gid = cgroup->control_uid = cgroup->tasks_gid =
-			cgroup->tasks_uid = NO_UID_GID;
+	cgroup->task_fperm = NO_PERMS;
+	cgroup->control_fperm = NO_PERMS;
+	cgroup->control_dperm = NO_PERMS;
+
+	cgroup->control_gid = NO_UID_GID;
+	cgroup->control_uid = NO_UID_GID;
+	cgroup->tasks_gid = NO_UID_GID;
+	cgroup->tasks_uid = NO_UID_GID;
 }
 
 void init_cgroup_table(struct cgroup *cgroups, size_t count)
@@ -44,48 +43,61 @@ void init_cgroup_table(struct cgroup *cgroups, size_t count)
 struct cgroup *cgroup_new_cgroup(const char *name)
 {
 	struct cgroup *cgroup = calloc(1, sizeof(struct cgroup));
+
 	if (!cgroup)
 		return NULL;
 
 	init_cgroup(cgroup);
-	strncpy(cgroup->name, name, sizeof(cgroup->name) - 1);
+	strncpy(cgroup->name, name, FILENAME_MAX - 1);
+	cgroup->name[FILENAME_MAX - 1] = '\0';
 
 	return cgroup;
 }
 
-struct cgroup_controller *cgroup_add_controller(struct cgroup *cgroup,
-							const char *name)
+struct cgroup_controller *cgroup_add_controller(struct cgroup *cgroup, const char *name)
 {
-	int i;
 	struct cgroup_controller *controller;
+	int i, ret;
 
 	if (!cgroup)
 		return NULL;
 
-	/*
-	 * Still not sure how to handle the failure here.
-	 */
+	/* Still not sure how to handle the failure here. */
 	if (cgroup->index >= CG_CONTROLLER_MAX)
 		return NULL;
 
-	/*
-	 * Still not sure how to handle the failure here.
-	 */
+	/* Still not sure how to handle the failure here. */
 	for (i = 0; i < cgroup->index; i++) {
-		if (strncmp(name, cgroup->controller[i]->name,
-				sizeof(cgroup->controller[i]->name)) == 0)
+		if (strncmp(name, cgroup->controller[i]->name, CONTROL_NAMELEN_MAX) == 0)
 			return NULL;
 	}
 
 	controller = calloc(1, sizeof(struct cgroup_controller));
-
 	if (!controller)
 		return NULL;
 
-	strncpy(controller->name, name, sizeof(controller->name) - 1);
+	strncpy(controller->name, name, CONTROL_NAMELEN_MAX - 1);
+	controller->name[CONTROL_NAMELEN_MAX - 1] = '\0';
+
 	controller->cgroup = cgroup;
 	controller->index = 0;
 
+	if (strcmp(controller->name, CGROUP_FILE_PREFIX) == 0) {
+		/*
+		 * Operating on the "cgroup" controller is only allowed
+		 * on cgroup v2 systems
+		 */
+		controller->version = CGROUP_V2;
+	} else {
+		ret = cgroup_get_controller_version(controller->name, &controller->version);
+		if (ret) {
+			cgroup_dbg("failed to get cgroup version for controller %s\n",
+				   controller->name);
+			free(controller);
+			return NULL;
+		}
+	}
+
 	cgroup->controller[cgroup->index] = controller;
 	cgroup->index++;
 
@@ -94,23 +106,24 @@ struct cgroup_controller *cgroup_add_controller(struct cgroup *cgroup,
 
 int cgroup_add_all_controllers(struct cgroup *cgroup)
 {
-	int ret;
-	void *handle;
-	struct controller_data info;
 	struct cgroup_controller *cgc;
+	struct controller_data info;
+	void *handle;
+	int ret;
 
 	/* go through the controller list */
 	ret = cgroup_get_all_controller_begin(&handle, &info);
 	if ((ret != 0) && (ret != ECGEOF)) {
-		fprintf(stderr, "cannot read controller data: %s\n",
-			cgroup_strerror(ret));
+		fprintf(stderr, "cannot read controller data: %s\n", cgroup_strerror(ret));
 		return ret;
 	}
 
 	while (ret == 0) {
 		if (info.hierarchy == 0) {
-			/* the controller is not attached to any hierarchy
-			   skip it */
+			/*
+			 * the controller is not attached to any
+			 * hierarchy skip it.
+			 */
 			goto next;
 		}
 
@@ -118,8 +131,8 @@ int cgroup_add_all_controllers(struct cgroup *cgroup)
 		cgc = cgroup_add_controller(cgroup, info.name);
 		if (!cgc) {
 			ret = ECGINVAL;
-			fprintf(stderr, "controller %s can't be add\n",
-				info.name);
+			fprintf(stderr, "controller %s can't be added\n", info.name);
+			goto end;
 		}
 
 next:
@@ -130,35 +143,46 @@ next:
 
 end:
 	cgroup_get_all_controller_end(&handle);
-
 	if (ret == ECGEOF)
 		ret = 0;
-
 	if (ret)
-		fprintf(stderr,
-			"cgroup_get_controller_begin/next failed (%s)\n",
+		fprintf(stderr,	"cgroup_get_controller_begin/next failed (%s)\n",
 			cgroup_strerror(ret));
 
 	return ret;
 }
 
+static void cgroup_free_value(struct control_value *value)
+{
+	if (value->multiline_value)
+		free(value->multiline_value);
+	if (value->prev_name)
+		free(value->prev_name);
+
+	free(value);
+}
+
+void cgroup_free_controller(struct cgroup_controller *ctrl)
+{
+	int i;
+
+	for (i = 0; i < ctrl->index; i++)
+		cgroup_free_value(ctrl->values[i]);
+	ctrl->index = 0;
+
+	free(ctrl);
+}
+
 void cgroup_free_controllers(struct cgroup *cgroup)
 {
-	int i, j;
+	int i;
 
 	if (!cgroup)
 		return;
 
-	for (i = 0; i < cgroup->index; i++) {
-		for (j = 0; j < cgroup->controller[i]->index; j++) {
-			if (cgroup->controller[i]->values[j]->multiline_value)
-				free(cgroup->controller[i]->values[j]->multiline_value);
+	for (i = 0; i < cgroup->index; i++)
+		cgroup_free_controller(cgroup->controller[i]);
 
-			free(cgroup->controller[i]->values[j]);
-		}
-		cgroup->controller[i]->index = 0;
-		free(cgroup->controller[i]);
-	}
 	cgroup->index = 0;
 }
 
@@ -166,9 +190,7 @@ void cgroup_free(struct cgroup **cgroup)
 {
 	struct cgroup *cg = *cgroup;
 
-	/*
-	 * Passing NULL pointers is OK. We just return.
-	 */
+	/* Passing NULL pointers is OK. We just return. */
 	if (!cg)
 		return;
 
@@ -177,8 +199,8 @@ void cgroup_free(struct cgroup **cgroup)
 	*cgroup = NULL;
 }
 
-int cgroup_add_value_string(struct cgroup_controller *controller,
-					const char *name, const char *value)
+int cgroup_add_value_string(struct cgroup_controller *controller, const char *name,
+			    const char *value)
 {
 	int i;
 	struct control_value *cntl_value;
@@ -195,7 +217,6 @@ int cgroup_add_value_string(struct cgroup_controller *controller,
 	}
 
 	cntl_value = calloc(1, sizeof(struct control_value));
-
 	if (!cntl_value)
 		return ECGCONTROLLERCREATEFAILED;
 
@@ -221,11 +242,10 @@ int cgroup_add_value_string(struct cgroup_controller *controller,
 	return 0;
 }
 
-int cgroup_add_value_int64(struct cgroup_controller *controller,
-					const char *name, int64_t value)
+int cgroup_add_value_int64(struct cgroup_controller *controller, const char *name, int64_t value)
 {
-	int ret;
 	char *val;
+	int ret;
 
 	ret = asprintf(&val, "%"PRId64, value);
 	if (ret < 0) {
@@ -239,11 +259,11 @@ int cgroup_add_value_int64(struct cgroup_controller *controller,
 	return ret;
 }
 
-int cgroup_add_value_uint64(struct cgroup_controller *controller,
-					const char *name, u_int64_t value)
+int cgroup_add_value_uint64(struct cgroup_controller *controller, const char *name,
+			    u_int64_t value)
 {
-	int ret;
 	char *val;
+	int ret;
 
 	ret = asprintf(&val, "%" PRIu64, value);
 	if (ret < 0) {
@@ -257,11 +277,10 @@ int cgroup_add_value_uint64(struct cgroup_controller *controller,
 	return ret;
 }
 
-int cgroup_add_value_bool(struct cgroup_controller *controller,
-						const char *name, bool value)
+int cgroup_add_value_bool(struct cgroup_controller *controller, const char *name, bool value)
 {
-	int ret;
 	char *val;
+	int ret;
 
 	if (value)
 		val = strdup("1");
@@ -278,8 +297,30 @@ int cgroup_add_value_bool(struct cgroup_controller *controller,
 	return ret;
 }
 
-int cgroup_compare_controllers(struct cgroup_controller *cgca,
-					struct cgroup_controller *cgcb)
+int cgroup_remove_value(struct cgroup_controller * const controller, const char * const name)
+{
+	int i;
+
+	for (i = 0; i < controller->index; i++) {
+		if (strcmp(controller->values[i]->name, name) == 0) {
+			cgroup_free_value(controller->values[i]);
+
+			if (i == (controller->index - 1)) {
+				/* This is the last entry in the table. There's nothing to move */
+				controller->index--;
+			} else {
+				memmove(&controller->values[i],	&controller->values[i + 1],
+				sizeof(struct control_value *) * (controller->index - i - 1));
+				controller->index--;
+			}
+			return 0;
+		}
+	}
+
+	return ECGROUPNOTEXIST;
+}
+
+int cgroup_compare_controllers(struct cgroup_controller *cgca, struct cgroup_controller *cgcb)
 {
 	int i;
 
@@ -302,6 +343,7 @@ int cgroup_compare_controllers(struct cgroup_controller *cgca,
 		if (strcmp(cva->value, cvb->value))
 			return ECGCONTROLLERNOTEQUAL;
 	}
+
 	return 0;
 }
 
@@ -337,11 +379,12 @@ int cgroup_compare_cgroup(struct cgroup *cgroup_a, struct cgroup *cgroup_b)
 		if (cgroup_compare_controllers(cgca, cgcb))
 			return ECGCONTROLLERNOTEQUAL;
 	}
+
 	return 0;
 }
 
-int cgroup_set_uid_gid(struct cgroup *cgroup, uid_t tasks_uid, gid_t tasks_gid,
-					uid_t control_uid, gid_t control_gid)
+int cgroup_set_uid_gid(struct cgroup *cgroup, uid_t tasks_uid, gid_t tasks_gid, uid_t control_uid,
+		       gid_t control_gid)
 {
 	if (!cgroup)
 		return ECGINVAL;
@@ -354,8 +397,8 @@ int cgroup_set_uid_gid(struct cgroup *cgroup, uid_t tasks_uid, gid_t tasks_gid,
 	return 0;
 }
 
-int cgroup_get_uid_gid(struct cgroup *cgroup, uid_t *tasks_uid,
-		gid_t *tasks_gid, uid_t *control_uid, gid_t *control_gid)
+int cgroup_get_uid_gid(struct cgroup *cgroup, uid_t *tasks_uid, gid_t *tasks_gid,
+		       uid_t *control_uid, gid_t *control_gid)
 {
 	if (!cgroup)
 		return ECGINVAL;
@@ -368,8 +411,7 @@ int cgroup_get_uid_gid(struct cgroup *cgroup, uid_t *tasks_uid,
 	return 0;
 }
 
-struct cgroup_controller *cgroup_get_controller(struct cgroup *cgroup,
-							const char *name)
+struct cgroup_controller *cgroup_get_controller(struct cgroup *cgroup, const char *name)
 {
 	int i;
 	struct cgroup_controller *cgc;
@@ -387,8 +429,7 @@ struct cgroup_controller *cgroup_get_controller(struct cgroup *cgroup,
 	return NULL;
 }
 
-int cgroup_get_value_string(struct cgroup_controller *controller,
-					const char *name, char **value)
+int cgroup_get_value_string(struct cgroup_controller *controller, const char *name, char **value)
 {
 	int i;
 
@@ -412,8 +453,8 @@ int cgroup_get_value_string(struct cgroup_controller *controller,
 
 }
 
-int cgroup_set_value_string(struct cgroup_controller *controller,
-					const char *name, const char *value)
+int cgroup_set_value_string(struct cgroup_controller *controller, const char *name,
+			    const char *value)
 {
 	int i;
 
@@ -422,6 +463,7 @@ int cgroup_set_value_string(struct cgroup_controller *controller,
 
 	for (i = 0; i < controller->index; i++) {
 		struct control_value *val = controller->values[i];
+
 		if (!strcmp(val->name, name)) {
 			strncpy(val->value, value, CG_VALUE_MAX);
 			val->value[sizeof(val->value)-1] = '\0';
@@ -433,8 +475,7 @@ int cgroup_set_value_string(struct cgroup_controller *controller,
 	return cgroup_add_value_string(controller, name, value);
 }
 
-int cgroup_get_value_int64(struct cgroup_controller *controller,
-					const char *name, int64_t *value)
+int cgroup_get_value_int64(struct cgroup_controller *controller, const char *name, int64_t *value)
 {
 	int i;
 
@@ -445,7 +486,6 @@ int cgroup_get_value_int64(struct cgroup_controller *controller,
 		struct control_value *val = controller->values[i];
 
 		if (!strcmp(val->name, name)) {
-
 			if (sscanf(val->value, "%" SCNd64, value) != 1)
 				return ECGINVAL;
 
@@ -456,11 +496,10 @@ int cgroup_get_value_int64(struct cgroup_controller *controller,
 	return ECGROUPVALUENOTEXIST;
 }
 
-int cgroup_set_value_int64(struct cgroup_controller *controller,
-					const char *name, int64_t value)
+int cgroup_set_value_int64(struct cgroup_controller *controller, const char *name, int64_t value)
 {
-	int i;
 	int ret;
+	int i;
 
 	if (!controller)
 		return ECGINVAL;
@@ -469,10 +508,8 @@ int cgroup_set_value_int64(struct cgroup_controller *controller,
 		struct control_value *val = controller->values[i];
 
 		if (!strcmp(val->name, name)) {
-			ret = snprintf(val->value,
-				sizeof(val->value), "%" PRId64, value);
-
-			if (ret >= sizeof(val->value) || ret < 0)
+			ret = snprintf(val->value, sizeof(val->value), "%" PRId64, value);
+			if (ret >= sizeof(val->value))
 				return ECGINVAL;
 
 			val->dirty = true;
@@ -483,8 +520,8 @@ int cgroup_set_value_int64(struct cgroup_controller *controller,
 	return cgroup_add_value_int64(controller, name, value);
 }
 
-int cgroup_get_value_uint64(struct cgroup_controller *controller,
-					const char *name, u_int64_t *value)
+int cgroup_get_value_uint64(struct cgroup_controller *controller, const char *name,
+			    u_int64_t *value)
 {
 	int i;
 
@@ -493,8 +530,8 @@ int cgroup_get_value_uint64(struct cgroup_controller *controller,
 
 	for (i = 0; i < controller->index; i++) {
 		struct control_value *val = controller->values[i];
-		if (!strcmp(val->name, name)) {
 
+		if (!strcmp(val->name, name)) {
 			if (sscanf(val->value, "%" SCNu64, value) != 1)
 				return ECGINVAL;
 
@@ -505,11 +542,11 @@ int cgroup_get_value_uint64(struct cgroup_controller *controller,
 	return ECGROUPVALUENOTEXIST;
 }
 
-int cgroup_set_value_uint64(struct cgroup_controller *controller,
-					const char *name, u_int64_t value)
+int cgroup_set_value_uint64(struct cgroup_controller *controller, const char *name,
+			    u_int64_t value)
 {
-	int i;
 	int ret;
+	int i;
 
 	if (!controller)
 		return ECGINVAL;
@@ -518,10 +555,8 @@ int cgroup_set_value_uint64(struct cgroup_controller *controller,
 		struct control_value *val = controller->values[i];
 
 		if (!strcmp(val->name, name)) {
-			ret = snprintf(val->value,
-				sizeof(val->value), "%" PRIu64, value);
-
-			if (ret >= sizeof(val->value) || ret < 0)
+			ret = snprintf(val->value, sizeof(val->value), "%" PRIu64, value);
+			if (ret >= sizeof(val->value))
 				return ECGINVAL;
 
 			val->dirty = true;
@@ -532,8 +567,7 @@ int cgroup_set_value_uint64(struct cgroup_controller *controller,
 	return cgroup_add_value_uint64(controller, name, value);
 }
 
-int cgroup_get_value_bool(struct cgroup_controller *controller,
-						const char *name, bool *value)
+int cgroup_get_value_bool(struct cgroup_controller *controller, const char *name, bool *value)
 {
 	int i;
 
@@ -557,14 +591,14 @@ int cgroup_get_value_bool(struct cgroup_controller *controller,
 			return 0;
 		}
 	}
+
 	return ECGROUPVALUENOTEXIST;
 }
 
-int cgroup_set_value_bool(struct cgroup_controller *controller,
-						const char *name, bool value)
+int cgroup_set_value_bool(struct cgroup_controller *controller, const char *name, bool value)
 {
-	int i;
 	int ret;
+	int i;
 
 	if (!controller)
 		return ECGINVAL;
@@ -573,15 +607,12 @@ int cgroup_set_value_bool(struct cgroup_controller *controller,
 		struct control_value *val = controller->values[i];
 
 		if (!strcmp(val->name, name)) {
-			if (value) {
-				ret = snprintf(val->value,
-						sizeof(val->value), "1");
-			} else {
-				ret = snprintf(val->value,
-						sizeof(val->value), "0");
-			}
+			if (value)
+				ret = snprintf(val->value, sizeof(val->value), "1");
+			else
+				ret = snprintf(val->value, sizeof(val->value), "0");
 
-			if (ret >= sizeof(val->value) || ret < 0)
+			if (ret >= sizeof(val->value))
 				return ECGINVAL;
 
 			val->dirty = true;
@@ -594,10 +625,10 @@ int cgroup_set_value_bool(struct cgroup_controller *controller,
 }
 
 struct cgroup *create_cgroup_from_name_value_pairs(const char *name,
-		struct control_value *name_value, int nv_number)
+						   struct control_value *name_value, int nv_number)
 {
-	struct cgroup *src_cgroup;
 	struct cgroup_controller *cgc;
+	struct cgroup *src_cgroup;
 	char con[FILENAME_MAX];
 
 	int ret;
@@ -606,50 +637,52 @@ struct cgroup *create_cgroup_from_name_value_pairs(const char *name,
 	/* create source cgroup */
 	src_cgroup = cgroup_new_cgroup(name);
 	if (!src_cgroup) {
-		fprintf(stderr, "can't create cgroup: %s\n",
-			cgroup_strerror(ECGFAIL));
+		fprintf(stderr, "can't create cgroup: %s\n", cgroup_strerror(ECGFAIL));
 		goto scgroup_err;
 	}
 
-	/* add pairs name-value to
-	   relevant controllers of this cgroup */
+	/* Add pairs name-value to relevant controllers of this cgroup. */
 	for (i = 0; i < nv_number; i++) {
 
 		if ((strchr(name_value[i].name, '.')) == NULL) {
-			fprintf(stderr, "wrong -r  parameter (%s=%s)\n",
-				name_value[i].name, name_value[i].value);
+			fprintf(stderr, "wrong -r  parameter (%s=%s)\n", name_value[i].name,
+				name_value[i].value);
 			goto scgroup_err;
 		}
 
 		strncpy(con, name_value[i].name, FILENAME_MAX - 1);
+		con[FILENAME_MAX - 1] = '\0';
+
 		strtok(con, ".");
 
-		/* find out whether we have to add the controller or
-		   cgroup already contains it */
+		/*
+		 * find out whether we have to add the controller or
+		 * cgroup already contains it.
+		 */
 		cgc = cgroup_get_controller(src_cgroup, con);
 		if (!cgc) {
 			/* add relevant controller */
 			cgc = cgroup_add_controller(src_cgroup, con);
 			if (!cgc) {
-				fprintf(stderr, "controller %s can't be add\n",
-						con);
+				fprintf(stderr, "controller %s can't be add\n",	con);
 				goto scgroup_err;
 			}
 		}
 
 		/* add name-value pair to this controller */
-		ret = cgroup_add_value_string(cgc,
-			name_value[i].name, name_value[i].value);
+		ret = cgroup_add_value_string(cgc, name_value[i].name, name_value[i].value);
 		if (ret) {
-			fprintf(stderr, "name-value pair %s=%s can't be set\n",
-				name_value[i].name, name_value[i].value);
+			fprintf(stderr, "name-value pair %s=%s can't be set\n",	name_value[i].name,
+				name_value[i].value);
 			goto scgroup_err;
 		}
 	}
 
 	return src_cgroup;
+
 scgroup_err:
 	cgroup_free(&src_cgroup);
+
 	return NULL;
 }
 
