@@ -1,3 +1,4 @@
+# SPDX-License-Identifier: LGPL-2.1-only
 #
 # Cgroup class for the libcgroup functional tests
 #
@@ -5,40 +6,28 @@
 # Author: Tom Hromatka <tom.hromatka@oracle.com>
 #
 
-#
-# This library is free software; you can redistribute it and/or modify it
-# under the terms of version 2.1 of the GNU Lesser General Public License as
-# published by the Free Software Foundation.
-#
-# This library is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
-# for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this library; if not, see <http://www.gnu.org/licenses>.
-#
-
-import consts
-import copy
+from container import ContainerError
 from controller import Controller
-from enum import Enum
-import multiprocessing as mp
-import os
 from run import Run, RunError
-import time
+import multiprocessing as mp
+from enum import Enum
+import consts
 import utils
+import time
+import copy
+import os
+
 
 class CgroupMount(object):
     def __init__(self, mount_line):
         entries = mount_line.split()
 
-        if entries[2] == "cgroup":
+        if entries[2] == 'cgroup':
             self.version = CgroupVersion.CGROUP_V1
-        elif entries[2] == "cgroup2":
+        elif entries[2] == 'cgroup2':
             self.version = CgroupVersion.CGROUP_V2
         else:
-            raise ValueError("Unknown cgroup version")
+            raise ValueError('Unknown cgroup version')
 
         self.mount_point = entries[1]
 
@@ -46,20 +35,21 @@ class CgroupMount(object):
         if self.version == CgroupVersion.CGROUP_V1:
             self.controller = entries[3].split(',')[-1]
 
-            if self.controller == "clone_children":
+            if self.controller == 'clone_children':
                 # the cpuset controller may append this option to the end
                 # rather than the controller name like all other controllers
-                self.controller = "cpuset"
+                self.controller = 'cpuset'
 
     def __str__(self):
-        out_str = "CgroupMount"
-        out_str += "\n\tMount Point = {}".format(self.mount_point)
-        out_str += "\n\tCgroup Version = {}".format(self.version)
+        out_str = 'CgroupMount'
+        out_str += '\n\tMount Point = {}'.format(self.mount_point)
+        out_str += '\n\tCgroup Version = {}'.format(self.version)
         if self.controller is not None:
-            out_str += "\n\tController = {}".format(self.controller)
+            out_str += '\n\tController = {}'.format(self.controller)
 
         return out_str
 
+
 class CgroupVersion(Enum):
     CGROUP_UNK = 0
     CGROUP_V1 = 1
@@ -77,13 +67,18 @@ class CgroupVersion(Enum):
                         if option == controller:
                             return CgroupVersion.CGROUP_V1
                 elif line.split()[0] == 'cgroup2':
-                    with open(os.path.join(mnt_path, 'cgroup.controllers'), 'r') as ctrlf:
+                    ctrlf_path = os.path.join(mnt_path, 'cgroup.controllers')
+                    with open(ctrlf_path, 'r') as ctrlf:
                         controllers = ctrlf.readline()
                         for ctrl in controllers.split():
                             if ctrl == controller:
                                 return CgroupVersion.CGROUP_V2
 
-        raise IndexError("Unknown version for controller {}".format(controller))
+        raise IndexError(
+                            'Unknown version for controller {}'
+                            ''.format(controller)
+                        )
+
 
 class Cgroup(object):
     # This class is analogous to libcgroup's struct cgroup
@@ -96,7 +91,7 @@ class Cgroup(object):
         self.children = list()
 
     def __str__(self):
-        out_str = "Cgroup {}\n".format(self.name)
+        out_str = 'Cgroup {}\n'.format(self.name)
         for ctrl_key in self.controllers:
             out_str += utils.indent(str(self.controllers[ctrl_key]), 4)
 
@@ -124,9 +119,10 @@ class Cgroup(object):
         return os.path.join(consts.LIBCG_MOUNT_POINT,
                             'src/daemon/{}'.format(cmd))
 
-    # TODO - add support for all of the cgcreate options
     @staticmethod
-    def create(config, controller_list, cgname):
+    def create(config, controller_list, cgname, user_name=None,
+               group_name=None, dperm=None, fperm=None, tperm=None,
+               tasks_user_name=None, tasks_group_name=None, cghelp=False):
         if isinstance(controller_list, str):
             controller_list = [controller_list]
 
@@ -136,8 +132,34 @@ class Cgroup(object):
             cmd.append('sudo')
         cmd.append(Cgroup.build_cmd_path('cgcreate'))
 
-        controllers_and_path = '{}:{}'.format(
-            ','.join(controller_list), cgname)
+        if user_name is not None and group_name is not None:
+            cmd.append('-a')
+            cmd.append('{}:{}'.format(user_name, group_name))
+
+        if dperm is not None:
+            cmd.append('-d')
+            cmd.append(dperm)
+
+        if fperm is not None:
+            cmd.append('-f')
+            cmd.append(fperm)
+
+        if tperm is not None:
+            cmd.append('-s')
+            cmd.append(tperm)
+
+        if tasks_user_name is not None and tasks_group_name is not None:
+            cmd.append('-t')
+            cmd.append('{}:{}'.format(tasks_user_name, tasks_group_name))
+
+        if cghelp:
+            cmd.append('-h')
+
+        if controller_list:
+            controllers_and_path = '{}:{}'.format(
+                ','.join(controller_list), cgname)
+        else:
+            controllers_and_path = ':{}'.format(cgname)
 
         cmd.append('-g')
         cmd.append(controllers_and_path)
@@ -161,8 +183,11 @@ class Cgroup(object):
         if recursive:
             cmd.append('-r')
 
-        controllers_and_path = '{}:{}'.format(
-            ''.join(controller_list), cgname)
+        if controller_list:
+            controllers_and_path = '{}:{}'.format(
+                ','.join(controller_list), cgname)
+        else:
+            controllers_and_path = ':{}'.format(cgname)
 
         cmd.append('-g')
         cmd.append(controllers_and_path)
@@ -173,43 +198,28 @@ class Cgroup(object):
             Run.run(cmd)
 
     @staticmethod
-    def set(config, cgname=None, setting=None, value=None, copy_from=None,
-            cghelp=False):
-        """cgset equivalent method
-
-        The following variants of cgset are being tested by the
-        automated functional tests:
-
-        Command                                          Test Number
-        cgset -r setting=value cgname                        various
-        cgset -r setting1=val1 -r setting2=val2
-              -r setting3=val2 cgname                            022
-        cgset --copy_from foo bar                                023
-        cgset --copy_from foo bar1 bar2                          024
-        cgset -r setting=value foo bar                           025
-        cgset -r setting1=value1 setting2=value2 foo bar         026
-        various invalid flag combinations                        027
-        """
-        cmd = list()
-
-        if not config.args.container:
-            cmd.append('sudo')
-        cmd.append(Cgroup.build_cmd_path('cgset'))
-
+    def __set(config, cmd, cgname=None, setting=None, value=None,
+              copy_from=None, cghelp=False):
         if setting is not None or value is not None:
             if isinstance(setting, str) and isinstance(value, str):
                 cmd.append('-r')
                 cmd.append('{}={}'.format(setting, value))
             elif isinstance(setting, list) and isinstance(value, list):
                 if len(setting) != len(value):
-                    raise ValueError('Settings list length must equal values list length')
+                    raise ValueError(
+                                        'Settings list length must equal '
+                                        'values list length'
+                                    )
 
                 for idx, stg in enumerate(setting):
                     cmd.append('-r')
                     cmd.append('{}={}'.format(stg, value[idx]))
             else:
-                raise ValueError('Invalid inputs to cgget:\nsetting: {}\n' \
-                                 'value{}'.format(setting, value))
+                raise ValueError(
+                                    'Invalid inputs to cgget:\nsetting: {}\n'
+                                    'value{}'
+                                    ''.format(setting, value)
+                                )
 
         if copy_from is not None:
             cmd.append('--copy-from')
@@ -232,32 +242,57 @@ class Cgroup(object):
             return Run.run(cmd)
 
     @staticmethod
-    def get(config, controller=None, cgname=None, setting=None,
-            print_headers=True, values_only=False,
-            all_controllers=False, cghelp=False):
-        """cgget equivalent method
+    def set(config, cgname=None, setting=None, value=None, copy_from=None,
+            cghelp=False):
+        """cgset equivalent method
 
-        Returns:
-        str: The stdout result of cgget
-
-        The following variants of cgget() are being tested by the
+        The following variants of cgset are being tested by the
         automated functional tests:
 
         Command                                          Test Number
-        cgget -r cpuset.cpus mycg                                001
-        cgget -r cpuset.cpus -r cpuset.mems mycg                 008
-        cgget -g cpu mycg                                        009
-        cgget -g cpu:mycg                                        010
-        cgget -r cpuset.cpus mycg1 mycg2                         011
-        cgget -r cpuset.cpus -r cpuset.mems mycg1 mycg2          012
-        cgget -g cpu -g freezer mycg                             013
-        cgget -a mycg                                            014
-        cgget -r memory.stat mycg (multiline value read)         015
-        various invalid flag combinations                        016
+        cgset -r setting=value cgname                        various
+        cgset -r setting1=val1 -r setting2=val2
+              -r setting3=val2 cgname                            022
+        cgset --copy_from foo bar                                023
+        cgset --copy_from foo bar1 bar2                          024
+        cgset -r setting=value foo bar                           025
+        cgset -r setting1=value1 setting2=value2 foo bar         026
+        various invalid flag combinations                        027
         """
         cmd = list()
-        cmd.append(Cgroup.build_cmd_path('cgget'))
+        if not config.args.container:
+            cmd.append('sudo')
+        cmd.append(Cgroup.build_cmd_path('cgset'))
 
+        return Cgroup.__set(config, cmd, cgname, setting, value, copy_from,
+                            cghelp)
+
+    @staticmethod
+    def xset(config, cgname=None, setting=None, value=None, copy_from=None,
+             version=CgroupVersion.CGROUP_UNK, cghelp=False,
+             ignore_unmappable=False):
+        """cgxset equivalent method
+        """
+        cmd = list()
+        if not config.args.container:
+            cmd.append('sudo')
+        cmd.append(Cgroup.build_cmd_path('cgxset'))
+
+        if version == CgroupVersion.CGROUP_V1:
+            cmd.append('-1')
+        elif version == CgroupVersion.CGROUP_V2:
+            cmd.append('-2')
+
+        if ignore_unmappable:
+            cmd.append('-i')
+
+        return Cgroup.__set(config, cmd, cgname, setting, value, copy_from,
+                            cghelp)
+
+    @staticmethod
+    def __get(config, cmd, controller=None, cgname=None, setting=None,
+              print_headers=True, values_only=False,
+              all_controllers=False, cghelp=False):
         if not print_headers:
             cmd.append('-n')
         if values_only:
@@ -308,16 +343,66 @@ class Cgroup(object):
         if config.args.container:
             ret = config.container.run(cmd)
         else:
-            try:
-                ret = Run.run(cmd)
-            except RunError as re:
-                if "profiling" in re.stderr:
-                    ret = re.stdout
-                else:
-                    raise re
+            ret = Run.run(cmd)
 
         return ret
 
+    @staticmethod
+    def get(config, controller=None, cgname=None, setting=None,
+            print_headers=True, values_only=False,
+            all_controllers=False, cghelp=False):
+        """cgget equivalent method
+
+        Returns:
+        str: The stdout result of cgget
+
+        The following variants of cgget() are being tested by the
+        automated functional tests:
+
+        Command                                          Test Number
+        cgget -r cpuset.cpus mycg                                001
+        cgget -r cpuset.cpus -r cpuset.mems mycg                 008
+        cgget -g cpu mycg                                        009
+        cgget -g cpu:mycg                                        010
+        cgget -r cpuset.cpus mycg1 mycg2                         011
+        cgget -r cpuset.cpus -r cpuset.mems mycg1 mycg2          012
+        cgget -g cpu -g freezer mycg                             013
+        cgget -a mycg                                            014
+        cgget -r memory.stat mycg (multiline value read)         015
+        various invalid flag combinations                        016
+        """
+        cmd = list()
+        cmd.append(Cgroup.build_cmd_path('cgget'))
+
+        return Cgroup.__get(config, cmd, controller, cgname, setting,
+                            print_headers, values_only, all_controllers,
+                            cghelp)
+
+    @staticmethod
+    def xget(config, controller=None, cgname=None, setting=None,
+             print_headers=True, values_only=False,
+             all_controllers=False, version=CgroupVersion.CGROUP_UNK,
+             cghelp=False, ignore_unmappable=False):
+        """cgxget equivalent method
+
+        Returns:
+        str: The stdout result of cgxget
+        """
+        cmd = list()
+        cmd.append(Cgroup.build_cmd_path('cgxget'))
+
+        if version == CgroupVersion.CGROUP_V1:
+            cmd.append('-1')
+        elif version == CgroupVersion.CGROUP_V2:
+            cmd.append('-2')
+
+        if ignore_unmappable:
+            cmd.append('-i')
+
+        return Cgroup.__get(config, cmd, controller, cgname, setting,
+                            print_headers, values_only, all_controllers,
+                            cghelp)
+
     @staticmethod
     def classify(config, controller, cgname, pid_list, sticky=False,
                  cancel_sticky=False):
@@ -343,7 +428,8 @@ class Cgroup(object):
             Run.run(cmd)
 
     @staticmethod
-    # given a stdout of cgsnapshot-like data, create a dictionary of cgroup objects
+    # given a stdout of cgsnapshot-like data, create a dictionary of cgroup
+    # objects
     def snapshot_to_dict(cgsnapshot_stdout):
         cgdict = dict()
 
@@ -362,10 +448,10 @@ class Cgroup(object):
             line = line.strip()
 
             if mode == parsemode.UNKNOWN:
-                if line.startswith("#"):
+                if line.startswith('#'):
                     continue
 
-                elif line.startswith("group") and line.endswith("{"):
+                elif line.startswith('group') and line.endswith('{'):
                     cg_name = line.split()[1]
                     if cg_name in cgdict:
                         # We already have a cgroup with this name.  This block
@@ -377,39 +463,39 @@ class Cgroup(object):
                     mode = parsemode.GROUP
 
             elif mode == parsemode.GROUP:
-                if line.startswith("perm {"):
+                if line.startswith('perm {'):
                     mode = parsemode.PERM
-                elif line.endswith("{"):
+                elif line.endswith('{'):
                     ctrl_name = line.split()[0]
                     cg.controllers[ctrl_name] = Controller(ctrl_name)
 
                     mode = parsemode.CONTROLLER
-                elif line.endswith("}"):
+                elif line.endswith('}'):
                     # we've found the end of this group
                     cgdict[cg_name] = cg
 
                     mode = parsemode.UNKNOWN
 
             elif mode == parsemode.CONTROLLER:
-                if line.endswith("\";"):
+                if line.endswith('";'):
                     # this is a setting on a single line
-                    setting = line.split("=")[0]
-                    value = line.split("=")[1]
+                    setting = line.split('=')[0]
+                    value = line.split('=')[1]
 
                     cg.controllers[ctrl_name].settings[setting] = value
 
-                elif line.endswith("}"):
+                elif line.endswith('}'):
                     # we've found the end of this controller
                     mode = parsemode.GROUP
 
                 else:
                     # this is a multi-line setting
-                    setting = line.split("=")[0]
-                    value = "{}\n".format(line.split("=")[1])
+                    setting = line.split('=')[0]
+                    value = '{}\n'.format(line.split('=')[1])
                     mode = parsemode.SETTING
 
             elif mode == parsemode.SETTING:
-                if line.endswith("\";"):
+                if line.endswith('";'):
                     # this is the last line of the multi-line setting
                     value += line
 
@@ -417,19 +503,19 @@ class Cgroup(object):
                     mode = parsemode.CONTROLLER
 
                 else:
-                    value += "{}\n".format(line)
+                    value += '{}\n'.format(line)
 
             elif mode == parsemode.PERM:
-                if line.startswith("admin {"):
+                if line.startswith('admin {'):
                     mode = parsemode.ADMIN
-                elif line.startswith("task {"):
+                elif line.startswith('task {'):
                     mode = parsemode.TASK
-                elif line.endswith("}"):
+                elif line.endswith('}'):
                     mode = parsemode.GROUP
 
             elif mode == parsemode.ADMIN or mode == parsemode.TASK:
                 # todo - handle these modes
-                if line.endswith("}"):
+                if line.endswith('}'):
                     mode = parsemode.PERM
 
         return cgdict
@@ -444,9 +530,13 @@ class Cgroup(object):
         # ensure the deny list file exists
         if config.args.container:
             try:
-                config.container.run(['sudo', 'touch', '/etc/cgsnapshot_blacklist.conf'])
+                config.container.run(
+                                        ['sudo',
+                                         'touch',
+                                         '/etc/cgsnapshot_blacklist.conf']
+                                    )
             except RunError as re:
-                if re.ret == 0 and "unable to resolve host" in re.stderr:
+                if re.ret == 0 and 'unable to resolve host' in re.stderr:
                     pass
         else:
             Run.run(['sudo', 'touch', '/etc/cgsnapshot_blacklist.conf'])
@@ -458,8 +548,10 @@ class Cgroup(object):
                 res = Run.run(cmd)
         except RunError as re:
             if re.ret == 0 and \
-               "neither blacklisted nor whitelisted" in re.stderr:
+               'neither blacklisted nor whitelisted' in re.stderr:
                 res = re.stdout
+            else:
+                raise(re)
 
         # convert the cgsnapshot stdout to a dict of cgroup objects
         return Cgroup.snapshot_to_dict(res)
@@ -492,6 +584,7 @@ class Cgroup(object):
 
         cmd.append('sudo')
         cmd.append('mkdir')
+        cmd.append('-p')
         cmd.append('/etc/cgconfig.d')
 
         try:
@@ -499,10 +592,8 @@ class Cgroup(object):
                 config.container.run(cmd, shell_bool=True)
             else:
                 Run.run(cmd, shell_bool=True)
-        except:
-            # todo - check the errno to ensure the directory exists rather
-            # than receiving a different error
-            pass
+        except RunError as re:
+            raise re
 
         cmd2 = list()
 
@@ -527,7 +618,10 @@ class Cgroup(object):
         cmd.append('-n')
 
         if config.args.container:
-            raise ValueError("Running cgrules within a container is not supported")
+            raise ValueError(
+                                'Running cgrules within a container is not '
+                                'supported'
+                            )
         else:
             Run.run(cmd, shell_bool=True)
 
@@ -549,7 +643,7 @@ class Cgroup(object):
                 config.container.run(cmd, shell_bool=True)
             else:
                 Run.run(cmd, shell_bool=True)
-        except:
+        except (RunError, ContainerError):
             # ignore any errors during the kill command.  this is belt
             # and suspenders code
             pass
@@ -628,9 +722,12 @@ class Cgroup(object):
                 if line.split()[0] == 'cgroup':
                     for option in line.split()[3].split(','):
                         if option == ctrl_name:
-                            return line.split()[1]
+                            return mnt_path
 
-        raise IndexError("Unknown mount point for controller {}".format(ctrl_name))
+        raise IndexError(
+                            'Unknown mount point for controller {}'
+                            ''.format(ctrl_name)
+                        )
 
     @staticmethod
     def __get_controller_mount_point_v2(ctrl_name):
@@ -648,7 +745,10 @@ class Cgroup(object):
                             if controller == ctrl_name:
                                 return mnt_path
 
-        raise IndexError("Unknown mount point for controller {}".format(ctrl_name))
+        raise IndexError(
+                            'Unknown mount point for controller {}'
+                            ''.format(ctrl_name)
+                        )
 
     @staticmethod
     def get_controller_mount_point(ctrl_name):
@@ -659,10 +759,11 @@ class Cgroup(object):
         elif vers == CgroupVersion.CGROUP_V2:
             return Cgroup.__get_controller_mount_point_v2(ctrl_name)
         else:
-            raise ValueError("Unsupported cgroup version")
+            raise ValueError('Unsupported cgroup version')
 
     @staticmethod
-    def clear(config, empty=False, cghelp=False, load_file=None, load_dir=None):
+    def clear(config, empty=False, cghelp=False, load_file=None,
+              load_dir=None):
         cmd = list()
 
         if not config.args.container:
@@ -713,13 +814,7 @@ class Cgroup(object):
         if config.args.container:
             ret = config.container.run(cmd)
         else:
-            try:
-                ret = Run.run(cmd)
-            except RunError as re:
-                if "profiling" in re.stderr:
-                    ret = re.stdout
-                else:
-                    raise re
+            ret = Run.run(cmd)
 
         return ret
 
@@ -731,20 +826,20 @@ class Cgroup(object):
             for line in mntf.readlines():
                 entry = line.split()
 
-                if entry[0] != "cgroup" and entry[0] != "cgroup2":
+                if entry[0] != 'cgroup' and entry[0] != 'cgroup2':
                     continue
 
                 mount = CgroupMount(line)
 
                 if mount.version == CgroupVersion.CGROUP_V1 or \
-                   expand_v2_mounts == False:
+                   expand_v2_mounts is False:
                     mount_list.append(mount)
                     continue
 
                 with open(os.path.join(mount.mount_point,
-                                       "cgroup.controllers")) as ctrlf:
-                    for line in ctrlf.readlines():
-                        for ctrl in line.split():
+                                       'cgroup.controllers')) as ctrlf:
+                    for ctrlf_line in ctrlf.readlines():
+                        for ctrl in ctrlf_line.split():
                             mount_copy = copy.deepcopy(mount)
                             mount_copy.controller = ctrl
                             mount_list.append(mount_copy)
@@ -774,13 +869,7 @@ class Cgroup(object):
         if config.args.container:
             ret = config.container.run(cmd)
         else:
-            try:
-                ret = Run.run(cmd)
-            except RunError as re:
-                if "profiling" in re.stderr:
-                    ret = re.stdout
-                else:
-                    raise re
+            ret = Run.run(cmd)
 
         return ret
 
@@ -821,7 +910,11 @@ class Cgroup(object):
 
         for mount in mounts:
             if mount.controller == controller:
-                proc_file = os.path.join(mount.mount_point, cgroup, "cgroup.procs")
+                proc_file = os.path.join(
+                                            mount.mount_point,
+                                            cgroup,
+                                            'cgroup.procs'
+                                        )
                 cmd = ['cat', proc_file]
 
                 if config.args.container:
@@ -830,3 +923,37 @@ class Cgroup(object):
                     return Run.run(cmd, shell_bool=True)
 
         return None
+
+    @staticmethod
+    def get_and_validate(config, cgname, setting, expected_value):
+        """get the requested setting and validate the value received
+
+        This is a helper method for the functional tests and there is no
+        equivalent libcgroup command line interface.  This method will
+        raise a CgroupError if the comparison fails
+        """
+        value = Cgroup.get(config, controller=None, cgname=cgname,
+                           setting=setting, print_headers=False,
+                           values_only=True)
+
+        if value != expected_value:
+            raise CgroupError('cgget expected {} but received {}'.format(
+                              expected_value, value))
+
+    @staticmethod
+    def set_and_validate(config, cgname, setting, value):
+        """set the requested setting and validate the write
+
+        This is a helper method for the functional tests and there is no
+        equivalent libcgroup command line interface.  This method will
+        raise a CgroupError if the comparison fails
+        """
+        Cgroup.set(config, cgname, setting, value)
+        Cgroup.get_and_validate(config, cgname, setting, value)
+
+
+class CgroupError(Exception):
+    def __init__(self, message):
+        super(CgroupError, self).__init__(message)
+
+# vim: set et ts=4 sw=4:
